#version 150


in  vec3 in_Position;
in	vec3 in_Position_Target;
in  vec3 in_Normal;
in	vec3 in_Normal_Target;

in  vec3 in_Color;
in	vec2 in_TexCoord;

out vec2 ex_fragTexCoord;
out vec3 fragNormal;
out vec3 fragEye;
out vec4 sm_tex_coord;
out float alpha;
out float dist[5];
out vec3 light[5];

	
uniform mat4 mvMat;
uniform mat4 vMat;
uniform mat4 projMat;
uniform vec3 ld;
uniform vec3 ld2;
uniform vec3 ld3;
uniform vec3 ld4;
uniform vec3 ld5;
uniform int nrLights;

uniform int mode;
uniform int interpolate;
uniform float dt;


void main(void)
{
	

	vec3 position;
	vec3 normal;
	vec3 lights;
	
	if(nrLights == 2) //not pretty, but for some reason much better performance than arrays
	{
		light[0] = ld;
		light[1] = ld2;	
	}else if(nrLights == 3)
	{
		light[0] = ld;
		light[1] = ld2;
		light[2] = ld3;

	}else if(nrLights == 4)
	{
		light[0] = ld;
		light[1] = ld2;
		light[2] = ld3;
		light[3] = ld4;
	}else{
		light[0] = ld;
	}
	
	if(interpolate == 1)
	{
		position.x = (1-dt) * in_Position.x + dt * in_Position_Target.x;
		position.y = (1-dt) * in_Position.y + dt * in_Position_Target.y;
		position.z = (1-dt) * in_Position.z + dt * in_Position_Target.z;
		
		normal.x = (1-dt) * in_Normal.x + dt * in_Normal_Target.x;
		normal.y = (1-dt) * in_Normal.y + dt * in_Normal_Target.y;
		normal.z = (1-dt) * in_Normal.z + dt * in_Normal_Target.z;
	}
	else
	{
		position = in_Position;
		normal = in_Normal;
	}
	alpha = clamp((100.0f / (mvMat * vec4(position,1)).z ) * (100.0f / (mvMat * vec4(position,1)).z ),0,1); 

	for(int i=0; i < nrLights; i++)
	{
		light[i] = (vMat * vec4(light[i],1)).xyz - (mvMat * vec4(position,1)).xyz; 
		dist[i] = length(light[i]);
		light[i] = normalize(light[i]);
	}
	
	
	fragNormal = (mvMat * vec4(normal, 0.0f)).xyz;
	
	fragEye = (mvMat * vec4(position, 1)).xyz;
	fragEye = -normalize(fragEye);
	
	ex_fragTexCoord.x = in_TexCoord.x;
	ex_fragTexCoord.y = -1 * in_TexCoord.y;

	//position calculation
	gl_Position = projMat *  mvMat * vec4(position,1);
	
}
